@@ -39,7 +39,6 @@ import (
 	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/img4"
 	"github.com/blacktop/ipsw/pkg/info"
-	"github.com/fatih/color"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -79,7 +78,7 @@ func init() {
 	downloadIpswCmd.Flags().Bool("fcs-keys", false, "Download AEA1 DMG fcs-key pem files")
 	downloadIpswCmd.Flags().Bool("fcs-keys-json", false, "Download AEA1 DMG fcs-keys as JSON")
 	downloadIpswCmd.Flags().Bool("decrypt", false, "Attempt to decrypt the partial files if keys are available")
-	downloadIpswCmd.Flags().BoolP("flat", "f", false, "Do NOT perserve directory structure when downloading with --pattern")
+	downloadIpswCmd.Flags().BoolP("flat", "f", false, "Do NOT preserve directory structure when downloading with --pattern")
 	downloadIpswCmd.Flags().BoolP("urls", "u", false, "Dump URLs only")
 	downloadIpswCmd.Flags().Bool("usb", false, "Download IPSWs for USB attached iDevices")
 	downloadIpswCmd.Flags().StringP("output", "o", "", "Folder to download files to")
@@ -143,11 +142,6 @@ var downloadIpswCmd = &cobra.Command{
 		var builds []download.Build
 		var filteredBuilds []download.Build
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// settings
 		proxy := viper.GetString("download.ipsw.proxy")
 		insecure := viper.GetBool("download.ipsw.insecure")
@@ -179,7 +173,7 @@ var downloadIpswCmd = &cobra.Command{
 		output := viper.GetString("download.ipsw.output")
 		flat := viper.GetBool("download.ipsw.flat")
 		// verify args
-		if len(device) == 0 && len(version) == 0 && len(build) == 0 {
+		if len(device) == 0 && len(version) == 0 && len(build) == 0 && !latest && !showLatestVersion && !showLatestBuild && !viper.GetBool("download.ipsw.urls") {
 			return fmt.Errorf("you must also supply a --device || --version || --build (or use --latest)")
 		}
 		if len(version) > 0 && len(build) > 0 {
@@ -322,7 +316,7 @@ var downloadIpswCmd = &cobra.Command{
 			}
 
 			if len(filteredBuilds) == 0 {
-				return fmt.Errorf(fmt.Sprintf("no IPSWs match device(s) %s %s", device, strings.Join(doDownload, " ")))
+				return fmt.Errorf("no IPSWs match device(s) %s %s", device, strings.Join(doDownload, " "))
 			}
 
 			// convert from itunes to ipsw
