@@ -25,12 +25,14 @@ package frida
 
 import (
 	"github.com/spf13/cobra"
+	"github.com/spf13/viper"
 )
 
 const fridaVersion = "17.2.0"
 
 func init() {
 	FridaCmd.PersistentFlags().StringP("udid", "u", "", "Device UniqueDeviceID to connect to")
+	viper.BindPFlag("frida.udid", FridaCmd.PersistentFlags().Lookup("udid"))
 }
 
 // FridaCmd represents the frida commands
