@@ -25,10 +25,8 @@ import (
 	"fmt"
 
 	"github.com/AlecAivazis/survey/v2"
-	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/usb/afc"
-	"github.com/fatih/color"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 )
@@ -37,6 +35,7 @@ func init() {
 	AfcCmd.AddCommand(idevAfcRmCmd)
 
 	idevAfcRmCmd.Flags().BoolP("recursive", "r", false, "recursive delete")
+	viper.BindPFlag("idev.afc.rm.recursive", idevAfcRmCmd.Flags().Lookup("recursive"))
 }
 
 // idevAfcRmCmd represents the rm command
@@ -44,17 +43,11 @@ var idevAfcRmCmd = &cobra.Command{
 	Use:           "rm",
 	Short:         "rm file rooted at /var/mobile/Media",
 	Args:          cobra.ExactArgs(1),
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
-		udid, _ := cmd.Flags().GetString("udid")
-		recursive, _ := cmd.Flags().GetBool("recursive")
+		udid := viper.GetString("idev.udid")
+		recursive := viper.GetBool("idev.afc.rm.recursive")
 
 		if len(udid) == 0 {
 			dev, err := utils.PickDevice()
