@@ -33,7 +33,6 @@ import (
 	"github.com/blacktop/ipsw/internal/commands/dwarf"
 	"github.com/blacktop/ipsw/internal/demangle"
 	"github.com/blacktop/ipsw/internal/utils"
-	"github.com/fatih/color"
 
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -202,15 +201,9 @@ var dwarfCmd = &cobra.Command{
 ❯ ipsw kernel dwarf --type task --diff
 # Diff ALL structs
 ❯ ipsw kernel dwarf --diff`,
-	SilenceUsage:  true,
 	SilenceErrors: true,
 	RunE: func(cmd *cobra.Command, args []string) error {
 
-		if viper.GetBool("verbose") {
-			log.SetLevel(log.DebugLevel)
-		}
-		color.NoColor = viper.GetBool("no-color")
-
 		// flags
 		// selectedArch := viper.GetString("kernel.dwarf.arch")
 		// prettyJSON := viper.GetBool("kernel.dwarf.pretty")
