@@ -15,10 +15,10 @@ import (
 	"github.com/alecthomas/chroma/v2/quick"
 	"github.com/apex/log"
 	"github.com/blacktop/go-macho"
+	"github.com/blacktop/go-macho/pkg/swift"
 	"github.com/blacktop/go-macho/types"
 	"github.com/blacktop/go-macho/types/objc"
 	"github.com/blacktop/go-plist"
-	"github.com/blacktop/ipsw/internal/swift"
 	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/tbd"
 )
@@ -37,6 +37,7 @@ type ObjcConfig struct {
 	ObjcRefs bool
 	Deps     bool
 	Generic  bool
+	Demangle bool
 
 	IpswVersion string
 
@@ -99,6 +100,13 @@ type headerInfo struct {
 	Object        string
 }
 
+func (o *ObjC) maybeDemangle(text string) string {
+	if !o.conf.Demangle {
+		return text
+	}
+	return swift.DemangleBlob(text)
+}
+
 // ObjC represents a MachO ObjC parser
 type ObjC struct {
 	conf  *ObjcConfig
@@ -180,16 +188,16 @@ func (o *ObjC) DumpClass(pattern string) error {
 			if re.MatchString(class.Name) {
 				if o.conf.Color {
 					if o.conf.Addrs {
-						quick.Highlight(os.Stdout, swift.DemangleBlob(class.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+						quick.Highlight(os.Stdout, o.maybeDemangle(class.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 					} else {
-						quick.Highlight(os.Stdout, swift.DemangleBlob(class.Verbose()), "objc", "terminal256", o.conf.Theme)
+						quick.Highlight(os.Stdout, o.maybeDemangle(class.Verbose()), "objc", "terminal256", o.conf.Theme)
 					}
 					quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 				} else {
 					if o.conf.Addrs {
-						fmt.Println(swift.DemangleBlob(class.WithAddrs()))
+						fmt.Println(o.maybeDemangle(class.WithAddrs()))
 					} else {
-						fmt.Println(swift.DemangleBlob(class.Verbose()))
+						fmt.Println(o.maybeDemangle(class.Verbose()))
 					}
 				}
 			}
@@ -227,16 +235,16 @@ func (o *ObjC) DumpProtocol(pattern string) error {
 				if _, ok := seen[proto.Ptr]; !ok { // prevent displaying duplicates
 					if o.conf.Color {
 						if o.conf.Addrs {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(proto.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(proto.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 						} else {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(proto.Verbose()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(proto.Verbose()), "objc", "terminal256", o.conf.Theme)
 						}
 						quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 					} else {
 						if o.conf.Addrs {
-							fmt.Println(swift.DemangleBlob(proto.WithAddrs()))
+							fmt.Println(o.maybeDemangle(proto.WithAddrs()))
 						} else {
-							fmt.Println(swift.DemangleBlob(proto.Verbose()))
+							fmt.Println(o.maybeDemangle(proto.Verbose()))
 						}
 					}
 					seen[proto.Ptr] = true
@@ -274,16 +282,16 @@ func (o *ObjC) DumpCategory(pattern string) error {
 			if re.MatchString(cat.Name) {
 				if o.conf.Color {
 					if o.conf.Addrs {
-						quick.Highlight(os.Stdout, swift.DemangleBlob(cat.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+						quick.Highlight(os.Stdout, o.maybeDemangle(cat.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 					} else {
-						quick.Highlight(os.Stdout, swift.DemangleBlob(cat.Verbose()), "objc", "terminal256", o.conf.Theme)
+						quick.Highlight(os.Stdout, o.maybeDemangle(cat.Verbose()), "objc", "terminal256", o.conf.Theme)
 					}
 					quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 				} else {
 					if o.conf.Addrs {
-						fmt.Println(swift.DemangleBlob(cat.WithAddrs()))
+						fmt.Println(o.maybeDemangle(cat.WithAddrs()))
 					} else {
-						fmt.Println(swift.DemangleBlob(cat.Verbose()))
+						fmt.Println(o.maybeDemangle(cat.Verbose()))
 					}
 				}
 			}
@@ -318,16 +326,16 @@ func (o *ObjC) Dump() error {
 					if o.conf.Verbose {
 						if o.conf.Color {
 							if o.conf.Addrs {
-								quick.Highlight(os.Stdout, swift.DemangleBlob(proto.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+								quick.Highlight(os.Stdout, o.maybeDemangle(proto.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 							} else {
-								quick.Highlight(os.Stdout, swift.DemangleBlob(proto.Verbose()), "objc", "terminal256", o.conf.Theme)
+								quick.Highlight(os.Stdout, o.maybeDemangle(proto.Verbose()), "objc", "terminal256", o.conf.Theme)
 							}
 							quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 						} else {
 							if o.conf.Addrs {
-								fmt.Println(swift.DemangleBlob(proto.WithAddrs()))
+								fmt.Println(o.maybeDemangle(proto.WithAddrs()))
 							} else {
-								fmt.Println(swift.DemangleBlob(proto.Verbose()))
+								fmt.Println(o.maybeDemangle(proto.Verbose()))
 							}
 						}
 					} else {
@@ -352,16 +360,16 @@ func (o *ObjC) Dump() error {
 				if o.conf.Verbose {
 					if o.conf.Color {
 						if o.conf.Addrs {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(class.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(class.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 						} else {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(class.Verbose()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(class.Verbose()), "objc", "terminal256", o.conf.Theme)
 						}
 						quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 					} else {
 						if o.conf.Addrs {
-							fmt.Println(swift.DemangleBlob(class.WithAddrs()))
+							fmt.Println(o.maybeDemangle(class.WithAddrs()))
 						} else {
-							fmt.Println(swift.DemangleBlob(class.Verbose()))
+							fmt.Println(o.maybeDemangle(class.Verbose()))
 						}
 					}
 				} else {
@@ -384,16 +392,16 @@ func (o *ObjC) Dump() error {
 				if o.conf.Verbose {
 					if o.conf.Color {
 						if o.conf.Addrs {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(cat.WithAddrs()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(cat.WithAddrs()), "objc", "terminal256", o.conf.Theme)
 						} else {
-							quick.Highlight(os.Stdout, swift.DemangleBlob(cat.Verbose()), "objc", "terminal256", o.conf.Theme)
+							quick.Highlight(os.Stdout, o.maybeDemangle(cat.Verbose()), "objc", "terminal256", o.conf.Theme)
 						}
 						quick.Highlight(os.Stdout, "\n/****************************************/\n\n", "objc", "terminal256", o.conf.Theme)
 					} else {
 						if o.conf.Addrs {
-							fmt.Println(swift.DemangleBlob(cat.WithAddrs()))
+							fmt.Println(o.maybeDemangle(cat.WithAddrs()))
 						} else {
-							fmt.Println(swift.DemangleBlob(cat.Verbose()))
+							fmt.Println(o.maybeDemangle(cat.Verbose()))
 						}
 					}
 				} else {
@@ -533,7 +541,7 @@ func (o *ObjC) Headers() error {
 				SourceVersion: sourceVersion,
 				Name:          class.Name,
 				Imports:       imps[class.Name],
-				Object:        swift.DemangleBlob(class.Verbose()),
+				Object:        o.maybeDemangle(class.Verbose()),
 			}); err != nil {
 				return err
 			}
@@ -581,7 +589,7 @@ func (o *ObjC) Headers() error {
 					SourceVersion: sourceVersion,
 					Name:          proto.Name + "_Protocol",
 					Imports:       imps[proto.Name+"-Protocol"],
-					Object:        swift.DemangleBlob(proto.Verbose()),
+					Object:        o.maybeDemangle(proto.Verbose()),
 				}); err != nil {
 					return err
 				}
@@ -618,7 +626,7 @@ func (o *ObjC) Headers() error {
 				SourceVersion: sourceVersion,
 				Name:          name,
 				Imports:       imps[cat.Name],
-				Object:        swift.DemangleBlob(cat.Verbose()),
+				Object:        o.maybeDemangle(cat.Verbose()),
 			}); err != nil {
 				return err
 			}
