@@ -223,6 +223,10 @@ const config = {
                 label: "Mastodon",
                 href: "https://mastodon.social/@blacktop",
               },
+              {
+                label: "Discord",
+                href: "https://discord.gg/BEamsHAWAh",
+              },
             ],
           },
           {
